from os import path
import drf_scaffold
from drf_scaffold.constants import MODEL_FIELDS

from django.core.management.templates import TemplateCommand


class Command(TemplateCommand):
    help = (
        "Creates a Django Rest Framework RESTFull CRUD app directory structure for the given app name in "
        "the current directory or optionally in the given directory."
    )
    missing_args_message = "You must provide an application name."

    def add_arguments(self, parser):
        parser.add_argument('--model', '-m', dest='model_name', help='Name of the model')
        
        parser.add_argument(
            '--fields', '-f', dest='fields',
            action='append', default=[],
            help='The fields name(s). Separate fields names '
                 'with commas, or use -f multiple times.'
        )
        super().add_arguments(parser)

    def handle(self, **options):
        app_name = options.pop('name')
        model_name = options.pop('model_name')
        fields = options.pop('fields')[0].split(',')
        options['template'] = path.join(drf_scaffold.__path__[0], 'conf', 'drf_app_template')
        options['model_name'] = model_name
        options['model_fields'] = [(field.split(':')[0].strip(), MODEL_FIELDS.get(field.split(':')[1])) for field in fields]
        options['camel_case_model_name'] = ''.join(x for x in model_name.title() if x != '_')
        super().handle('app', app_name, **options)



import codecs
import re
import os
import setuptools


def get_version(filename):
    with codecs.open(filename, 'r', 'utf-8') as fp:
        contents = fp.read()
    return re.search(r"__version__ = ['\"]([^'\"]+)['\"]", contents).group(1)

NAME = 'drf_scaffold'
VERSION = get_version(os.path.join('drf_scaffold', '__init__.py'))
DESCRIPTION = 'Dead simple custom command to create a django app with djando rest framework CRUD RESTFull API'
URL = 'https://github.com/juliosmelo/drf_scaffold'
AUTHOR = 'juliocsmelo'
AUTHOR_EMAIL = 'juliocsmelo@gmail.com'
LICENSE = 'MIT'
PACKAGES=[
        'drf_scaffold',
        'drf_scaffold.management',
        'drf_scaffold.management.commands']
REQUIREMENTS = ['Django>=1.11', 'djangorestframework>=3.7.3']
CLASSIFIERS=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: System :: Installation/Setup']

setuptools.setup(name=NAME,
      version=VERSION,
      description=DESCRIPTION,
      url=URL,
      author=AUTHOR,
      author_email=AUTHOR_EMAIL,
      license=LICENSE,
      packages=PACKAGES,
      install_requires=REQUIREMENTS,
      classifiers=CLASSIFIERS,
      zip_safe=False)




MODEL_FIELDS = {
    "string": "CharField(max_length=200)",
    "integer": "IntegerField()",
    "decimal": "DecimalField()",
    "positive": "PositiveIntegerField()",
    "auto": "AutoField()",
    "bigauto": "BigAutoField()",
    "bigint": "BigIntegerField()",
    "binary": "BinaryField()",
    "boolean": "BooleanField()",
    "date": "DateField()",
    "datetime": "DateTimeField()",
    "duration": "DurationField()",
    "email": "EmailField()",
    "file": "FileField()",
    "filepath": "FilePathField()",
    "float": "FloatField()",
    "image": "ImageField()",
    "genericip": "GenericIPAddressField()",
    "nullboolean": "NullBooleanField()",
    "positiveint": "PositiveIntegerField()",
    "positivesmalint": "PositiveSmallIntegerField()",
    "slug": "SlugField()",
    "smallint": "SmallIntegerField()",
    "text": "TextField()",
    "time": "TimeField()",
    "url": "URLField()",
    "uuid": "UUIDField()"
}